@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.122';
+our $VERSION = '0.123';
 use 5.006;
 use strict;
 use warnings;
@@ -99,7 +99,7 @@ sub run {
 	my ($session) = $j->_dispatch($auth, $pkg->new());
 	
 	my $req = $j->params->req;
-	$req =~ /^([a-z][0-9a-zA-Z_]{1,31})$/; $req = $1 // '';
+	$req =~ /^([a-z][0-9a-zA-Z_]{1,31})$/ && do { $req = $1 // '' } if $req;
 	$req = $j->{_application}->preprocess_req($req, $j) if $j->{_application}->can('preprocess_req');
 	if (!$req || !$session || $PRIVATE{$req}) {
 		$j->response->raiseError('Invalid request', 400);
@@ -379,7 +379,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.122
+Version 0.123
 
 =cut
 
