@@ -34,7 +34,7 @@ sub preprocess_req {
                         	}
                 	}
 		}
-		$req = $self->SUPER::preprocess_req($req, $t);
+		$req = $self->SUPER::preprocess_req($req, $t) if ! $req;
         	($req) = $t->request->uri->path =~ m/([^\/]+)$/ if ! $req;
 	}
         return $req;
@@ -104,6 +104,20 @@ sub _load_modules {
 		die $@ && next if $@;
 		$mods{_alias} = { %{$mods{_alias} || {}}, %{$Terse::Controller::dispatcher{ref $module}{_alias} || {}} }; 
 		$mods{_alias}{$module->capture} = { namespace => $module->namespace } if $module->{capture};
+		my $in;
+		$in = sub {
+			my @ISA = eval "\@$_[0]::ISA";
+			for (@ISA) {
+				$in->($_);
+				my $dispatch = $Terse::Controller::dispatcher{$_};
+				$mods{_alias} = {%{$dispatch->{_alias} || {}}, %{$mods{_alias} || {}}}; 
+			}
+		};
+		$in->(ref $module);
+
+
+
+
 		$mods{$module->namespace} = $module;
 	}
 	return \%mods;
@@ -174,7 +188,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.122
+Version 0.123
 
 =cut
 
